# Dump HLS

A python package to dump any HLS stream as it is

## Usage
### Installation
* From source code: `make install`
* From PyPI: `pip install dump_hls`


## Development
Install dependencies:
```shell
make deps
```

Run tests:
```shell
make test
```

Other scripts:
```shell
make help
```

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the `pypackage` project template of 
[cookiecutter-templates]().

